How Malaya gathered corpus?
============================

.. note::

    This tutorial is available as an IPython notebook
    `here <https://github.com/huseinzol05/Malaya/blob/master/translator/translator.ipynb>`_.

.. include:: translator.rst
